==> docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0/luna-sdk_alma_rel_v.5.32.0/doc/fsdk/html/search/enumvalues_9.js <==
var searchData=
[
  ['landmarkcount',['LandmarkCount',['../structfsdk_1_1_landmarks5_indexes.html#a9eae145170941117cc76738a0c0a5ff7aec5fb21288f98e092c4fb19e9fd9dc3c',1,'fsdk::Landmarks5Indexes']]],
  ['landmarklefteye',['LandmarkLeftEye',['../structfsdk_1_1_landmarks5_indexes.html#a9eae145170941117cc76738a0c0a5ff7ad3566c44c6de999dfc157bc178093e94',1,'fsdk::Landmarks5Indexes']]],
  ['landmarkmouthleftcorner',['LandmarkMouthLeftCorner',['../structfsdk_1_1_landmarks5_indexes.html#a9eae145170941117cc76738a0c0a5ff7a8e22313b8661da3a61347417a8e61ca6',1,'fsdk::Landmarks5Indexes']]],
  ['landmarkmouthrightcorner',['LandmarkMouthRightCorner',['../structfsdk_1_1_landmarks5_indexes.html#a9eae145170941117cc76738a0c0a5ff7a69e618c0af0d1130966997ad32b5e4b0',1,'fsdk::Landmarks5Indexes']]],
  ['landmarknose',['LandmarkNose',['../structfsdk_1_1_landmarks5_indexes.html#a9eae145170941117cc76738a0c0a5ff7a572a622e295b81f5ee4578e7e290aa39',1,'fsdk::Landmarks5Indexes']]],
  ['landmarkrighteye',['LandmarkRightEye',['../structfsdk_1_1_landmarks5_indexes.html#a9eae145170941117cc76738a0c0a5ff7aca84a9be871065c03172c26db6fc025c',1,'fsdk::Landmarks5Indexes']]],
  ['lefteye',['LeftEye',['../group___occlusion_estimator_group.html#gga8b3ddce447c4f06eb4413fc267796a26abf33bb6b1088e0b535e68ad4093ef477',1,'fsdk']]],
  ['licenseactivationlimitexceeded',['LicenseActivationLimitExceeded',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6af951c3475ff430374472dc8dcaa533a5',1,'fsdk']]],
  ['licenseerror',['LicenseError',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a2b423836b373458d26bdc9da85cfc6a8',1,'fsdk']]],
  ['licenseisnotactivated',['LicenseIsNotActivated',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a22e90664663be51d76eb78ba6e964375',1,'fsdk']]],
  ['long',['Long',['../structfsdk_1_1_human_attribute_result.html#a5b39f39ce497f8870f4acfc5f032efeda8394f0347c184cf156ac5924dccb773b',1,'fsdk::HumanAttributeResult']]],
  ['lowerface',['LowerFace',['../group___occlusion_estimator_group.html#gga8b3ddce447c4f06eb4413fc267796a26a23993577eda41e0509da12131a90dc45',1,'fsdk']]]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.34.0/luna-sdk_alma_rel_v.5.34.0/doc/fsdk/html/search/enumvalues_9.js <==
var searchData=
[
  ['landmarkcount',['LandmarkCount',['../structfsdk_1_1_landmarks5_indexes.html#a9eae145170941117cc76738a0c0a5ff7aec5fb21288f98e092c4fb19e9fd9dc3c',1,'fsdk::Landmarks5Indexes']]],
  ['landmarklefteye',['LandmarkLeftEye',['../structfsdk_1_1_landmarks5_indexes.html#a9eae145170941117cc76738a0c0a5ff7ad3566c44c6de999dfc157bc178093e94',1,'fsdk::Landmarks5Indexes']]],
  ['landmarkmouthleftcorner',['LandmarkMouthLeftCorner',['../structfsdk_1_1_landmarks5_indexes.html#a9eae145170941117cc76738a0c0a5ff7a8e22313b8661da3a61347417a8e61ca6',1,'fsdk::Landmarks5Indexes']]],
  ['landmarkmouthrightcorner',['LandmarkMouthRightCorner',['../structfsdk_1_1_landmarks5_indexes.html#a9eae145170941117cc76738a0c0a5ff7a69e618c0af0d1130966997ad32b5e4b0',1,'fsdk::Landmarks5Indexes']]],
  ['landmarknose',['LandmarkNose',['../structfsdk_1_1_landmarks5_indexes.html#a9eae145170941117cc76738a0c0a5ff7a572a622e295b81f5ee4578e7e290aa39',1,'fsdk::Landmarks5Indexes']]],
  ['landmarkrighteye',['LandmarkRightEye',['../structfsdk_1_1_landmarks5_indexes.html#a9eae145170941117cc76738a0c0a5ff7aca84a9be871065c03172c26db6fc025c',1,'fsdk::Landmarks5Indexes']]],
  ['lefteye',['LeftEye',['../group___occlusion_estimator_group.html#gga8b3ddce447c4f06eb4413fc267796a26abf33bb6b1088e0b535e68ad4093ef477',1,'fsdk']]],
  ['licenseactivationlimitexceeded',['LicenseActivationLimitExceeded',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6af951c3475ff430374472dc8dcaa533a5',1,'fsdk']]],
  ['licenseerror',['LicenseError',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a2b423836b373458d26bdc9da85cfc6a8',1,'fsdk']]],
  ['licenseisnotactivated',['LicenseIsNotActivated',['../namespacefsdk.html#a811cc08198c8cb908dc856217ef6c4f6a22e90664663be51d76eb78ba6e964375',1,'fsdk']]],
  ['light',['Light',['../structfsdk_1_1_light_colored_clothes_estimation.html#ac9e69ae4fab2f62191098e7593862b27a9914a0ce04a7b7b6a8e39bec55064b82',1,'fsdk::LightColoredClothesEstimation']]],
  ['long',['Long',['../structfsdk_1_1_human_attribute_result.html#a5b39f39ce497f8870f4acfc5f032efeda8394f0347c184cf156ac5924dccb773b',1,'fsdk::HumanAttributeResult']]],
  ['lowerface',['LowerFace',['../group___occlusion_estimator_group.html#gga8b3ddce447c4f06eb4413fc267796a26a23993577eda41e0509da12131a90dc45',1,'fsdk']]]
];
